;; Generated package description from aggressive-completion.el  -*- no-byte-compile: t -*-
(define-package "aggressive-completion" "1.6.0.20220414.42707" "Automatic minibuffer completion" '((emacs "27.1")) :commit "d7bfb380b8b9f56582558f944d648fb17a42f9fb" :url "https://elpa.gnu.org/packages/aggressive-completion.html" :authors '(("Tassilo Horn" . "tsdh@gnu.org")) :maintainer '("Tassilo Horn" . "tsdh@gnu.org") :keywords '("minibuffer" "completion"))
